@@ -25,21 +25,27 @@
 # ===========================================================================
 
 import unittest
+
 import mapscript
+
 from .testing import MapTestCase
 
 
 class DrawProgrammedStylesTestCase(MapTestCase):
     def testDrawPoints(self):
         """DrawProgrammedStylesTestCase.testDrawPoints: point drawing with styles works as advertised"""
-        points = [mapscript.pointObj(-0.2, 51.6),
-                  mapscript.pointObj(0.0, 51.2),
-                  mapscript.pointObj(0.2, 51.6)]
-        colors = [mapscript.colorObj(255, 0, 0),
-                  mapscript.colorObj(0, 255, 0),
-                  mapscript.colorObj(0, 0, 255)]
+        points = [
+            mapscript.pointObj(-0.2, 51.6),
+            mapscript.pointObj(0.0, 51.2),
+            mapscript.pointObj(0.2, 51.6),
+        ]
+        colors = [
+            mapscript.colorObj(255, 0, 0),
+            mapscript.colorObj(0, 255, 0),
+            mapscript.colorObj(0, 0, 255),
+        ]
         img = self.map.prepareImage()
-        layer = self.map.getLayerByName('POINT')
+        layer = self.map.getLayerByName("POINT")
         # layer.draw(self.map, img)
         class0 = layer.getClass(0)
         for i in range(len(points)):
@@ -48,11 +54,10 @@ class DrawProgrammedStylesTestCase(MapTestCase):
             # style0.color.pen = -4
             assert style0.color.toHex() == colors[i].toHex()
             points[i].draw(self.map, layer, img, 0, "foo")
-        img.save('test_draw_points.png')
+        img.save("test_draw_points.png")
 
 
 class NewStylesTestCase(MapTestCase):
-
     def testStyleConstructor(self):
         """a new style is properly initialized"""
         new_style = mapscript.styleObj()
@@ -63,10 +68,10 @@ class NewStylesTestCase(MapTestCase):
     def testCloneStyle(self):
         """check attributes of a cloned style"""
         new_style = mapscript.styleObj()
-        new_style.color.setHex('#808080')
+        new_style.color.setHex("#808080")
         clone = new_style.clone()
         assert clone.thisown == 1
-        assert clone.color.toHex() == '#808080'
+        assert clone.color.toHex() == "#808080"
 
     def testStyleColorSettable(self):
         """a style can be set with a color tuple"""
@@ -79,32 +84,32 @@ class NewStylesTestCase(MapTestCase):
     def testStyleBinding(self):
         """attribute binding can be set and get"""
         new_style = mapscript.styleObj()
-        assert (not new_style.getBinding(mapscript.MS_STYLE_BINDING_COLOR))
+        assert not new_style.getBinding(mapscript.MS_STYLE_BINDING_COLOR)
         new_style.setBinding(mapscript.MS_STYLE_BINDING_COLOR, "NEW_BINDING")
-        assert (new_style.getBinding(mapscript.MS_STYLE_BINDING_COLOR) == "NEW_BINDING")
+        assert new_style.getBinding(mapscript.MS_STYLE_BINDING_COLOR) == "NEW_BINDING"
 
     def testAppendNewStyle(self):
         """a new style can be appended properly"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
         assert class0.numstyles == 2, class0.numstyles
         new_style = mapscript.styleObj()
         new_style.color.setRGB(0, 0, 0)
-        new_style.setSymbolByName(self.map, 'circle')
+        new_style.setSymbolByName(self.map, "circle")
         new_style.size = 3
         index = class0.insertStyle(new_style)
         assert index == 2, index
         assert class0.numstyles == 3, class0.numstyles
         msimg = self.map.draw()
         assert msimg.thisown == 1
-        filename = 'testAppendNewStyle.png'
-        fh = open(filename, 'wb')
+        filename = "testAppendNewStyle.png"
+        fh = open(filename, "wb")
         msimg.write(fh)
         fh.close()
 
     def testAppendNewStyleOldWay(self):
         """NewStylesTestCase.testAppendNewStyleOldWay: a new style can be appended properly using old method"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
         assert class0.numstyles == 2, class0.numstyles
         new_style = mapscript.styleObj(class0)
@@ -113,14 +118,14 @@ class NewStylesTestCase(MapTestCase):
         new_style.symbol = 1
         new_style.size = 3
         msimg = self.map.draw()
-        filename = 'testAppendNewStyleOldWay.png'
-        fh = open(filename, 'wb')
+        filename = "testAppendNewStyleOldWay.png"
+        fh = open(filename, "wb")
         msimg.write(fh)
         fh.close()
 
     def testInsertNewStyleAtIndex0(self):
         """NewStylesTestCase.testInsertNewStyleAtIndex0: a new style can be inserted ahead of all others"""
-        l_layer = self.map.getLayerByName('LINE')
+        l_layer = self.map.getLayerByName("LINE")
         class0 = l_layer.getClass(0)
         new_style = mapscript.styleObj()
         new_style.color.setRGB(255, 255, 0)
@@ -131,46 +136,47 @@ class NewStylesTestCase(MapTestCase):
         assert class0.numstyles == 2, class0.numstyles
         msimg = self.map.draw()
         assert msimg.thisown == 1
-        filename = 'testInsertNewStyleAtIndex0.png'
-        fh = open(filename, 'wb')
+        filename = "testInsertNewStyleAtIndex0.png"
+        fh = open(filename, "wb")
         msimg.write(fh)
         fh.close()
 
     def testRemovePointStyle(self):
         """NewStylesTestCase.testRemovePointStyle: a point style can be properly removed"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
         rem_style = class0.removeStyle(1)
         assert rem_style is not None
         assert class0.numstyles == 1, class0.numstyles
         msimg = self.map.draw()
-        filename = 'testRemovePointStyle.png'
+        filename = "testRemovePointStyle.png"
         msimg.save(filename)
 
     def testModifyMultipleStyle(self):
         """NewStylesTestCase.testModifyMultipleStyle: multiple styles can be modified"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
         style1 = class0.getStyle(1)
         style1.color.setRGB(255, 255, 0)
         msimg = self.map.draw()
-        filename = 'testModifyMutiplePointStyle.png'
+        filename = "testModifyMultiplePointStyle.png"
         msimg.save(filename)
 
     def testInsertStylePastEnd(self):
         """NewStylesTestCase.testInsertStylePastEnd: inserting a style past the end of
         the list raises the proper error"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
         new_style = mapscript.styleObj()
-        self.assertRaises(mapscript.MapServerChildError, class0.insertStyle, new_style, 6)
+        self.assertRaises(
+            mapscript.MapServerChildError, class0.insertStyle, new_style, 6
+        )
 
     def testInsertNULLStyle(self):
         """attempt to insert a NULL style should raise error"""
-        p_layer = self.map.getLayerByName('POINT')
+        p_layer = self.map.getLayerByName("POINT")
         class0 = p_layer.getClass(0)
-        self.assertRaises(mapscript.MapServerChildError,
-                          class0.insertStyle, None)
+        self.assertRaises(mapscript.MapServerChildError, class0.insertStyle, None)
 
     def testConvertToString(self):
         """ensure styles can be created and output to strings
@@ -249,10 +255,9 @@ class NewStylesTestCase(MapTestCase):
 
 
 class BrushCachingTestCase(MapTestCase):
-
     def testDrawMapWithSecondPolygon(self):
         """draw a blue polygon and a red polygon"""
-        p = self.map.getLayerByName('POLYGON')
+        p = self.map.getLayerByName("POLYGON")
         ip = mapscript.layerObj(self.map)
         ip.type = mapscript.MS_LAYER_POLYGON
         ip.status = mapscript.MS_DEFAULT
@@ -275,13 +280,15 @@ class BrushCachingTestCase(MapTestCase):
         s0 = p.getShape(res)
         p.close()
         r0 = s0.bounds
-        r1 = mapscript.rectObj(r0.minx-0.1, r0.miny-0.1, r0.maxx-0.1, r0.maxy-0.1)
+        r1 = mapscript.rectObj(
+            r0.minx - 0.1, r0.miny - 0.1, r0.maxx - 0.1, r0.maxy - 0.1
+        )
         s1 = r1.toPolygon()
 
         ip.addFeature(s1)
         img = self.map.draw()
-        img.save('test_drawmapw2ndpolygon.png')
+        img.save("test_drawmapw2ndpolygon.png")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
